@@ -9,30 +9,34 @@
 
 #include "mactab.h"
 #include <QAbstractItemModel>
+#include <QObject>
 #include <QSet>
+#include <QString>
+#include <QVariant>
+#include <Qt>
+#include <utility>
 
-namespace fcitx {
-namespace unikey {
+namespace fcitx::unikey {
 class MacroModel : public QAbstractTableModel {
     Q_OBJECT
 public:
     explicit MacroModel(QObject *parent = 0);
     virtual ~MacroModel();
 
-    virtual QVariant headerData(int section, Qt::Orientation orientation,
-                                int role = Qt::DisplayRole) const;
-    virtual int rowCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual int columnCount(const QModelIndex &parent = QModelIndex()) const;
-    virtual QVariant data(const QModelIndex &index,
-                          int role = Qt::DisplayRole) const;
+    QVariant headerData(int section, Qt::Orientation orientation,
+                        int role = Qt::DisplayRole) const override;
+    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    QVariant data(const QModelIndex &index,
+                  int role = Qt::DisplayRole) const override;
     void load(CMacroTable *table);
     void addItem(const QString &macro, const QString &word);
     void deleteItem(int row);
     void deleteAllItem();
     void save(CMacroTable *table);
-    bool needSave();
+    bool needSave() const;
 
-signals:
+Q_SIGNALS:
     void needSaveChanged(bool);
 
 private:
@@ -41,7 +45,7 @@ private:
     QSet<QString> keyset_;
     QList<std::pair<QString, QString>> list_;
 };
-} // namespace unikey
-} // namespace fcitx
+
+} // namespace fcitx::unikey
 
 #endif // _MACRO_EDITOR_MODEL_H_
