@@ -101,6 +101,12 @@ void UnikeyInputContext::putChar(unsigned int ch) {
     backspaces_ = 0;
 }
 
+//--------------------------------------------
+void UnikeyInputContext::rebuildChar(VnLexiName ch) {
+    bufChars_ = sizeof(buf_);
+    engine_.rebuildChar(ch, backspaces_, buf_, bufChars_);
+}
+
 //--------------------------------------------
 void UnikeyInputContext::resetBuf() { engine_.reset(); }
 
